pub struct GetGuildChannels<'a> { /* private fields */ }Expand description
Get the channels in a guild.
Channel Obfuscation
Channels the user does not have access to will not be returned via this endpoint once Discord finalizes the rollout of Channel Obfuscation on or around November 16th, 2026.